--
-- Macroscript for the UVCopy Tool
-- (C) 2000 Lostboys Games
--

global UVCopyToolIsActive = false


macroScript UVCopyTool
	category:"UVCopyTool"
	toolTip:"Copies a set of uv coordinates, materials and more from one object to another object"
(
	UVCopyToolIsActive = true
	local FromObject
	local ToObject
	local CopyMat = true
	local CopyColorCh = true


	--
	-- main rollout:
	--
	rollout uvcopy_main "Settings"(

		pickbutton PickFromObject "Pick Source Object"		width:160		tooltip:"Pick the source object"
		pickbutton PickToObject "Pick Destination Object"	width:160		tooltip:"Pick the destination object"

		checkbox CopyMaterial "Copy Material" checked:CopyMat
		checkbox CopyColorChannel "Copy Color Channel" checked:CopyColorCh

		button DoSwitch "Copy!" width:160	tooltip:"Copy the mapping data from the source object to the destination object"

		on PickFromObject picked obj do (
			FromObject = obj
			PickFromObject.text = obj.name
		)

		on PickToObject picked obj do (
			ToObject = obj
			PickToObject.text = obj.name
		)

		on CopyMaterial changed state do CopyMat = state
		on CopyColorChannel changed state do CopyColorCh = state

		on DoSwitch pressed do (
			if (FromObject != ToObject) then (
				if ((iskindof FromObject Editable_Mesh) == true) then(
					if ((iskindof ToObject.baseobject Editable_Mesh) == true) then( -- LAM: line modified. A sphere with a Bend modifier would pass the original test
						ToMesh=ToObject.baseobject.mesh  -- LAM: always want to work with the baseobject mesh
						if ((getNumVerts FromObject) == (getNumVerts ToMesh)) then(
							if ((getNumFaces FromObject) == (getNumFaces ToMesh)) then(

								--
								-- Materials:
								--
								if (CopyMat == true) then (
									ToObject.Material = FromObject.Material			-- Copy Materials
									nrfaces = (getNumFaces FromObject)
									for i = 1 to nrfaces do (
										setFaceMatID ToMesh i (getFaceMatID FromObject i)		-- Copy material ID's in the faces
									)
								)



								--
								-- UVW's:
								--

								meshop.setNumMaps ToMesh (meshop.getNumMaps FromObject)
								for mapnr = (if (CopyColorCh==true) then 1 else 2) to 100 do(
									if ((meshop.GetMapSupport FromObject mapnr)==true) then (
										meshop.SetMapSupport ToMesh mapnr (meshop.GetMapSupport FromObject mapnr)

										--
										-- First the vertices:
										--
										nrverts = meshop.getNumMapVerts FromObject mapnr
										meshop.setNumMapVerts ToMesh mapnr nrverts
										for i = 1 to nrverts do (
											meshop.setMapVert ToMesh mapnr i (meshop.getMapVert FromObject mapnr i)
										)


										--
										-- Now the faces:
										--

										nrfaces = meshop.getNumMapFaces FromObject mapnr

										for i = 1 to nrfaces do (
											meshop.setMapFace ToMesh mapnr i (meshop.getMapFace FromObject mapnr i)
										)
									)
								)
								update ToObject -- LAM: added line to force mesh and object update
								MessageBox "Finished copying UV coordinates"
							)

							else MessageBox "Meshes differ in number of faces! Cannot copy UV's"

						)
						else MessageBox "Meshes differ in number of vertices! Cannot copy UV's"

					)
					else MessageBox "To-Object is not an editable mesh!"

				)
				else MessageBox "From-Object is not an editable mesh!"

			)
			else MessageBox "Objects are the same! Cannot copy UV's to the same object"

		)
	)

	--
	-- about rollout:
	--

	rollout uvcopy_about "About"(
		label coreexport_about1  "UV Copy Tool"
		label coreexport_about2  "Version 1.0"
		label coreexport_about3  "http://www.games.lostboys.com"
		label coreexport_about4  ""
		label coreexport_about5  "(c) 2000 Lost Boys Games"
		label coreexport_about6  ""
		label coreexport_about13 "Idea: Kees Rijnen"
		label coreexport_about14 ""
		label coreexport_about7  "Programmed by"
		label coreexport_about8  "Nick Waanders"
		label coreexport_about9  "nick.waanders@games.lostboys.nl"
		label coreexport_about10 ""
		label coreexport_about11 "Special thanks to:"
		label coreexport_about12 "Larry Minton (author of avg_dlx)"
	)


	uvcopy_floater = newrolloutfloater "UV Copy Tool" 200 210 200 100					-- create the floater

	addrollout uvcopy_main		uvcopy_floater											-- add the main rollout
	addrollout uvcopy_about		uvcopy_floater rolledup:true							-- add the about rollout
)


